==> vue-renderless-3.8.0.tgz: package/column-list-item/vue.js <==
import "../chunk-G2ADBYYC.js";
import {
  handelIconClick,
  handleChange,
  getIsGroup,
  getSize,
  isDisabled,
  getModel,
  setModel,
  computedStore
} from "./index";
const api = ["state", "handelIconClick"];
const renderless = (props, { reactive, watch, computed }, { vm, parent, emit, constants, nextTick, dispatch }) => {
  const api2 = {};
  const state = reactive({
    columnGroup: {},
    itemChecked: props.modelValue,
    sliceNum: computed(() => props.size === "small" ? 1 : 2),
    iconNum: computed(() => props.size === "small" ? 2 : 3),
    effectOptions: computed(() => props.options.filter((item) => !item.hidden)),
    showCheckbox: computed(() => props.showCheckbox || state.columnGroup.showCheckbox),
    store: computed(() => api2.computedStore()),
    getIsGroup: computed(() => api2.getIsGroup()),
    size: computed(() => api2.getSize()),
    disabled: computed(() => api2.isDisabled()),
    model: computed({
      get: () => api2.getModel(),
      set: (val) => api2.setModel(val)
    })
  });
  Object.assign(api2, {
    state,
    getSize: getSize({ props, state }),
    getModel: getModel({ props, state }),
    getIsGroup: getIsGroup({ constants, parent, state }),
    isDisabled: isDisabled({ props, state }),
    setModel: setModel({ constants, dispatch, emit, props, vm, state }),
    handleChange: handleChange({ constants, dispatch, emit, state, nextTick }),
    computedStore: computedStore({ state, props }),
    handelIconClick: handelIconClick({ emit })
  });
  watch(() => state.model, api2.handleChange, { deep: true });
  return api2;
};
export {
  api,
  renderless
};

==> vue-renderless-3.24.0.tgz: package/column-list-item/vue.js <==
import "../chunk-G2ADBYYC.js";
import {
  getModel,
  setModel,
  handelIconClick,
  computedStore,
  getItemChecked,
  handleChange,
  getIsGroup,
  getSize,
  isDisabled,
  computedOptions,
  getType
} from "./index";
const api = ["state", "handelIconClick", "handleChange"];
const renderless = (props, { reactive, computed }, { vm, parent, emit, nextTick, dispatch, constants }) => {
  const api2 = {};
  const state = reactive({
    columnGroup: {},
    type: computed(() => api2.getType()),
    size: computed(() => api2.getSize()),
    disabled: computed(() => api2.isDisabled()),
    itemChecked: computed(() => api2.getItemChecked()),
    sliceNum: computed(() => props.size === "small" ? 1 : 2),
    iconNum: computed(() => props.size === "small" ? 2 : 3),
    showCheckbox: computed(() => props.showCheckbox || state.columnGroup.showCheckbox),
    showRadio: computed(() => props.showRadio || state.columnGroup.showRadio),
    store: computed(() => api2.computedStore()),
    effectOptions: computed(() => api2.computedOptions()),
    isGroup: computed(() => api2.getIsGroup()),
    model: computed({
      get: () => api2.getModel(),
      set: (val) => api2.setModel(val)
    })
  });
  Object.assign(api2, {
    state,
    getIsGroup: getIsGroup({ constants, parent, state }),
    isDisabled: isDisabled({ props, state }),
    setModel: setModel({ constants, dispatch, emit, props, vm, state }),
    getSize: getSize({ props, state }),
    getModel: getModel({ props, state }),
    handleChange: handleChange({ constants, dispatch, emit, state, nextTick }),
    computedStore: computedStore({ state, props }),
    handelIconClick: handelIconClick({ emit }),
    getItemChecked: getItemChecked({ state, props }),
    computedOptions: computedOptions({ props }),
    getType: getType({ props, state })
  });
  return api2;
};
export {
  api,
  renderless
};
